.. _utils_ref:

Utility functions
=================

The :mod:`sktime.utils` module contains utility functions.

.. automodule:: sktime.utils
    :no-members:
    :no-inherited-members:

Plotting
--------

.. currentmodule:: sktime.utils.plotting

.. autosummary::
    :toctree: auto_generated/
    :template: function.rst

    plot_series
    plot_lags
    plot_correlations

Data Processing
---------------

.. currentmodule:: sktime.datatypes._panel._convert

.. autosummary::
    :toctree: auto_generated/
    :template: function.rst

    are_columns_nested
    is_nested_dataframe
    from_nested_to_2d_array
    from_2d_array_to_nested
    from_3d_numpy_to_2d_array
    from_3d_numpy_to_nested
    from_nested_to_3d_numpy
    from_multi_index_to_3d_numpy
    from_3d_numpy_to_multi_index
    from_multi_index_to_nested
    from_nested_to_multi_index
    from_nested_to_long
    from_long_to_nested
